Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(487)

Unified Diff: components/sync/engine/fake_sync_engine.h

Issue 2533083002: [Sync] SyncEngine refactor part 1: interfaces. (Closed)
Patch Set: Rebase. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/sync/driver/sync_service.h ('k') | components/sync/engine/fake_sync_engine.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/sync/engine/fake_sync_engine.h
diff --git a/components/sync/driver/glue/sync_backend_host_mock.h b/components/sync/engine/fake_sync_engine.h
similarity index 89%
rename from components/sync/driver/glue/sync_backend_host_mock.h
rename to components/sync/engine/fake_sync_engine.h
index 66b5a26e25eba21b868ae6d4b8728254942e40b0..68e93474701fdfb7e8decf4430a740786b6a7a9f 100644
--- a/components/sync/driver/glue/sync_backend_host_mock.h
+++ b/components/sync/engine/fake_sync_engine.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef COMPONENTS_SYNC_DRIVER_GLUE_SYNC_BACKEND_HOST_MOCK_H_
-#define COMPONENTS_SYNC_DRIVER_GLUE_SYNC_BACKEND_HOST_MOCK_H_
+#ifndef COMPONENTS_SYNC_ENGINE_FAKE_SYNC_ENGINE_H_
+#define COMPONENTS_SYNC_ENGINE_FAKE_SYNC_ENGINE_H_
#include <memory>
#include <string>
@@ -11,23 +11,23 @@
#include "base/callback.h"
#include "base/compiler_specific.h"
#include "components/sync/base/weak_handle.h"
-#include "components/sync/driver/glue/sync_backend_host.h"
+#include "components/sync/engine/sync_engine.h"
namespace syncer {
-// A mock of the SyncBackendHost.
+// A mock of the SyncEngine.
//
// This class implements the bare minimum required for the ProfileSyncService to
// get through initialization. It often returns null pointers or nonesense
// values; it is not intended to be used in tests that depend on SyncBackendHost
// behavior.
-class SyncBackendHostMock : public SyncBackendHost {
+class FakeSyncEngine : public SyncEngine {
public:
- SyncBackendHostMock();
- ~SyncBackendHostMock() override;
+ FakeSyncEngine();
+ ~FakeSyncEngine() override;
void Initialize(
- SyncFrontend* frontend,
+ SyncEngineHost* host,
scoped_refptr<base::SingleThreadTaskRunner> sync_task_runner,
const WeakHandle<JsEventHandler>& event_handler,
const GURL& service_url,
@@ -118,4 +118,4 @@ class SyncBackendHostMock : public SyncBackendHost {
} // namespace syncer
-#endif // COMPONENTS_SYNC_DRIVER_GLUE_SYNC_BACKEND_HOST_MOCK_H_
+#endif // COMPONENTS_SYNC_ENGINE_FAKE_SYNC_ENGINE_H_
« no previous file with comments | « components/sync/driver/sync_service.h ('k') | components/sync/engine/fake_sync_engine.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -11,23 +11,23 @@
// This class implements the bare minimum required for the ProfileSyncService to
// get through initialization. It often returns null pointers or nonesense
-// values; it is not intended to be used in tests that depend on SyncBackendHost
+// values; it is not intended to be used in tests that depend on SyncEngine
// behavior.
This is Rietveld 408576698